# Bazaar-Dl

[![Upload Python Package](https://github.com/Matin-B/Bazaar-Dl/actions/workflows/main.yml/badge.svg)](https://github.com/Matin-B/Bazaar-Dl/actions/workflows/main.yml)

Simple Python package for direct download applications from Cafe Bazaar (CafeBazaar.ir)


## Install package
```console
pip install Bazaar-Dl
```

## Examples of How To Use 

Get tweet info

```python
from bazaar_dl import download

# Get tweet information from Twitter
download("com.mtni.myirancell")
```